:tocdepth: 1

.. |grappelli| replace:: Grappelli
.. |filebrowser| replace:: FileBrowser

.. _changelog:

Changelog
=========

3.14.2 (not yet released)
-------------------------

3.14.1 (April 22nd 2021)
------------------------

* Compatibility with Django 3.2 and Grappelli 2.15

3.13.3 (April 22nd 2021)
------------------------

* Fixed: Post upload signal sends wrong fileobject if file already exists.
* Fixed: Django doc links.

3.13.2 (Nov 25th 2020)
----------------------

* Compatibility with Django 3.1
* Fixed Quickstart
* Fixed display of errors with upload template
* Added version qualities
* Added support for TinyMCE v5

3.13.1 (May 15th 2020)
----------------------

* Compatibility with Django 3.0 and Grappelli 2.14

For further information, see :ref:`releasenotes`.
